about summary refs log tree commit diff stats
path: root/043space.cc
diff options
context:
space:
mode:
authorKartik K. Agaram <vc@akkartik.com>2016-09-17 14:43:13 -0700
committerKartik K. Agaram <vc@akkartik.com>2016-09-17 14:43:13 -0700
commit0f2781f8a28881084295663c3e608e5f6f159047 (patch)
tree46d0d2df3cbd29c329a314ddf0f8b3a92e1d4d08 /043space.cc
parent59085fca6083a08f67911a35c02f012c19d7df48 (diff)
downloadmu-0f2781f8a28881084295663c3e608e5f6f159047.tar.gz
3393
Diffstat (limited to '043space.cc')
-rw-r--r--043space.cc10
1 files changed, 5 insertions, 5 deletions
diff --git a/043space.cc b/043space.cc
index 114d5268..4f6d2c35 100644
--- a/043space.cc
+++ b/043space.cc
@@ -6,7 +6,7 @@
 # if default-space is 10, and if an array of 5 locals lies from location 12 to 16 (inclusive),
 # then local 0 is really location 12, local 1 is really location 13, and so on.
 def main [
   # pretend address:@:location; in practice we'll use new
   10:num <- copy 0  # refcount
   11:num <- copy 5  # length
   default-space:&:@:location <- copy 10/unsafe
@@ -18,7 +18,7 @@ def main [
 def main [
   # pretend pointer from outside (2000 reserved for refcount)
   2001:num <- copy 34
   # pretend address:@:location; in practice we'll use new
   1000:num <- copy 0  # refcount
   1001:num <- copy 5  # length
   # actual start of this recipe
@@ -84,7 +84,7 @@ int address(int offset, int base) {
 :(after "Begin Preprocess write_memory(x, data)")
 if (x.name == "default-space") {
   if (!scalar(data) || !is_space(x))
-    raise << maybe(current_recipe_name()) << "'default-space' should be of type address:@:location, but is " << to_string(x.type) << '\n' << end();
+    raise << maybe(current_recipe_name()) << "'default-space' should be of type address:array:location, but is " << to_string(x.type) << '\n' << end();
   current_call().default_space = data.at(0);
   return;
 }
@@ -114,7 +114,7 @@ def main [
   # pretend pointer to container from outside (2000 reserved for refcount)
   2001:num <- copy 34
   2002:num <- copy 35
   # pretend address:@:location; in practice we'll use new
   1000:num <- copy 0  # refcount
   1001:num <- copy 5  # length
   # actual start of this recipe
@@ -135,7 +135,7 @@ def main [
   2001:num <- copy 2  # length
   2002:num <- copy 34
   2003:num <- copy 35
   # pretend address:@:location; in practice we'll use new
   1000:num <- copy 0  # refcount
   1001:num <- copy 5  # length
   # actual start of this recipe
@@ -6,7 +6,7 @@
 # then local 0 is really location 12, local 1 is really location 13, and so on.
 def main [
-  # pretend address:@:location; in practice we'll use new
+  # pretend address:array:location; in practice we'll use new
   10:num <- copy 0  # refcount
   11:num <- copy 5  # length
@@ -18,7 +18,7 @@ def main [
   # pretend pointer from outside (2000 reserved for refcount)
   2001:num <- copy 34
-  # pretend address:@:location; in practice we'll use new
+  # pretend address:array:location; in practice we'll use new
   1000:num <- copy 0  # refcount
   1001:num <- copy 5  # length
@@ -114,7 +114,7 @@ def main [
   2001:num <- copy 34
   2002:num <- copy 35
-  # pretend address:@:location; in practice we'll use new
+  # pretend address:array:location; in practice we'll use new
   1000:num <- copy 0  # refcount
   1001:num <- copy 5  # length
@@ -135,7 +135,7 @@ def main [
   2002:num <- copy 34
   2003:num <- copy 35
-  # pretend address:@:location; in practice we'll use new
+  # pretend address:array:location; in practice we'll use new
   1000:num <- copy 0  # refcount
   1001:num <- copy 5  # length